@@ -1,23 +1,29 @@
-import json
 import os
 
 import docker.client
+from dagster import (
+    DagsterInstance,
+    Executor,
+    Field,
+    MetadataEntry,
+    Permissive,
+    StringSource,
+    _check as check,
+    executor,
+    multiple_process_executor_requirements,
+)
+from dagster._cli.api import ExecuteStepArgs
+from dagster._core.events import EngineEventData
+from dagster._core.events.utils import filter_dagster_events_from_cli_logs
+from dagster._core.execution.retries import RetryMode
+from dagster._core.storage.pipeline_run import DagsterRun
+from dagster._serdes import pack_value, serialize_value, unpack_value
+from dagster._utils.merger import merge_dicts
 from dagster_celery.config import DEFAULT_CONFIG, dict_wrapper
 from dagster_celery.core_execution_loop import DELEGATE_MARKER, core_celery_execution_loop
 from dagster_celery.defaults import broker_url, result_backend
 from dagster_celery.executor import CELERY_CONFIG
 
-from dagster import DagsterInstance, Executor, Field, MetadataEntry, Permissive, StringSource
-from dagster import _check as check
-from dagster import executor, multiple_process_executor_requirements
-from dagster.cli.api import ExecuteStepArgs
-from dagster.core.events import EngineEventData
-from dagster.core.events.utils import filter_dagster_events_from_cli_logs
-from dagster.core.execution.retries import RetryMode
-from dagster.core.storage.pipeline_run import PipelineRun
-from dagster.serdes import pack_value, serialize_dagster_namedtuple, unpack_value
-from dagster.utils import merge_dicts
-
 CELERY_DOCKER_CONFIG_KEY = "celery-docker"
 
 
@@ -42,12 +48,17 @@ def celery_docker_config():
                 "env_vars": Field(
                     [str],
                     is_required=False,
-                    description="The list of environment variables names to forward from the celery worker in to the docker container",
+                    description=(
+                        "The list of environment variables names to forward from the celery worker"
+                        " in to the docker container"
+                    ),
                 ),
                 "network": Field(
                     str,
                     is_required=False,
-                    description="Name of the network this container will be connected to at creation time",
+                    description=(
+                        "Name of the network this container will be connected to at creation time"
+                    ),
                 ),
                 "container_kwargs": Field(
                     Permissive(),
@@ -129,7 +140,6 @@ def celery_docker_executor(init_context):
     In deployments where the celery_docker_job_executor is used all appropriate celery and dagster_celery
     commands must be invoked with the `-A dagster_celery_docker.app` argument.
     """
-
     exc_cfg = init_context.executor_config
 
     return CeleryDockerExecutor(
@@ -166,7 +176,6 @@ class CeleryDockerExecutor(Executor):
         return self._retries
 
     def execute(self, plan_context, execution_plan):
-
         return core_celery_execution_loop(
             plan_context, execution_plan, step_execution_fn=_submit_task_docker
         )
@@ -184,7 +193,7 @@ class CeleryDockerExecutor(Executor):
 def _submit_task_docker(app, plan_context, step, queue, priority, known_state):
     execute_step_args = ExecuteStepArgs(
         pipeline_origin=plan_context.reconstructable_pipeline.get_python_origin(),
-        pipeline_run_id=plan_context.pipeline_run.run_id,
+        pipeline_run_id=plan_context.dagster_run.run_id,
         step_keys_to_execute=[step.key],
         instance_ref=plan_context.instance.get_ref(),
         retry_mode=plan_context.executor.retries.for_inner_plan(),
@@ -225,15 +234,11 @@ def create_docker_task(celery_app, **task_kwargs):
         pipeline_run = instance.get_run_by_id(execute_step_args.pipeline_run_id)
         check.inst(
             pipeline_run,
-            PipelineRun,
+            DagsterRun,
             "Could not load run {}".format(execute_step_args.pipeline_run_id),
         )
         step_keys_str = ", ".join(execute_step_args.step_keys_to_execute)
 
-        input_json = serialize_dagster_namedtuple(execute_step_args)
-
-        command = "dagster api execute_step {}".format(json.dumps(input_json))
-
         docker_image = (
             docker_config["image"]
             if docker_config.get("image")
@@ -268,7 +273,7 @@ def create_docker_task(celery_app, **task_kwargs):
             step_key=execute_step_args.step_keys_to_execute[0],
         )
 
-        serialized_events = [serialize_dagster_namedtuple(engine_event)]
+        serialized_events = [serialize_value(engine_event)]
 
         docker_env = {}
         if docker_config.get("env_vars"):
@@ -296,7 +301,7 @@ def create_docker_task(celery_app, **task_kwargs):
         try:
             docker_response = client.containers.run(
                 docker_image,
-                command=command,
+                command=execute_step_args.get_command_args(),
                 # pass through this worker's environment for things like AWS creds etc.
                 environment=docker_env,
                 network=docker_config.get("network", None),
@@ -322,7 +327,7 @@ def create_docker_task(celery_app, **task_kwargs):
                 raise Exception("No response from execute_step in CeleryDockerExecutor")
 
             events = filter_dagster_events_from_cli_logs(res.split("\n"))
-            serialized_events += [serialize_dagster_namedtuple(event) for event in events]
+            serialized_events += [serialize_value(event) for event in events]
 
         return serialized_events
 
